name = "pybis"
__author__ = "Swen Vermeul • ID SIS • ETH Zürich"
__email__ = "swen@ethz.ch"
__version__ = "1.33.2"

from . import pybis
from .pybis import DataSet
from .pybis import Openbis
